import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { MoneyFlowIndexIndicator } from "./MoneyFlowIndexIndicator";
/**
 * Represents a IgxDataChartComponent Money Flow Index indicator series.
 * Default required members: Close, Low, High, Volume
*
* Represents a Ignite UIDataChart Money Flow Index indicator series.
*
* Example:
*
* ```ts
*  <IgrDataChart
*     dataSource={this.state.dataSource} >
*
*     <IgrCategoryXAxis name="xAxis" />
*     <IgrNumericYAxis name="yAxis" />
*
*     <IgrMoneyFlowIndexIndicator
* 	name="series1"
* 	openMemberPath="open"
* 	volumeMemberPath="Volume"
* 	highMemberPath="High"
* 	lowMemberPath="Low"
* 	closeMemberPath="close"/>
*  </IgrDataChart>
* ```
*
* ```ts
* this.series = new IgrrMoneyFlowIndexIndicator ({ name: "Series1" });
* this.series.dataSource = this.data;
* this.series.xAxis = this.categoryXAxis;
* this.series.yAxis = this.numericYAxis;
* this.series.volumeMemberPath="Volume" ;
* this.series.highMemberPath= "High" ;
* this.series.lowMemberPath="Low" ;
* this.series.closeMemberPath="close"
* ```
*/
var IgrMoneyFlowIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMoneyFlowIndexIndicator, _super);
    function IgrMoneyFlowIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrMoneyFlowIndexIndicator.prototype.createImplementation = function () {
        return new MoneyFlowIndexIndicator();
    };
    Object.defineProperty(IgrMoneyFlowIndexIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoneyFlowIndexIndicator.prototype, "defaultDisplayType", {
        /**
         * Gets default display type for the current Financial Indicator
        */
        get: function () {
            return this.i.x6;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoneyFlowIndexIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
         * The typical, and initial, value for MoneyFlowIndexIndicator periods is 14.
        *
        * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
        *
        * Example:
        *
        * ```ts
        * this.series.period = 14;
        * ```
        *
        * ```ts
        *  <IgrDataChart
        *     dataSource={this.state.dataSource} >
        *
        *     <IgrCategoryXAxis name="xAxis" />
        *     <IgrNumericYAxis name="yAxis" />
        *
        *     <IgrMoneyFlowIndexIndicator
        * 	name="series1"
        * 	openMemberPath="open"
        * 	volumeMemberPath="Volume"
        * 	highMemberPath="High"
        * 	lowMemberPath="Low"
        * 	closeMemberPath="close"
        * 	period="14"/>
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.zk;
        },
        set: function (v) {
            this.i.zk = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrMoneyFlowIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrMoneyFlowIndexIndicator };
