import * as React from 'react';
import { CategoryChart } from './CategoryChart';
import { CategoryChartType } from './CategoryChartType';
import { CategorySeriesMarkerCollisionAvoidance } from './CategorySeriesMarkerCollisionAvoidance';
import { CategoryTransitionInMode } from './CategoryTransitionInMode';
import { TransitionInSpeedType } from './TransitionInSpeedType';
import { IgrXYChart, IIgrXYChartProps } from './igr-xy-chart';
import { DataSeriesType } from "igniteui-react-core";
import { DomainType } from "./DomainType";
import { AxisRangeBufferMode } from './AxisRangeBufferMode';
import { AutoMarginsAndAngleUpdateMode } from './AutoMarginsAndAngleUpdateMode';
/**
 * Represents a chart with an ordinal X-axis and a numeric Y-axis.
*
* **Ignite UI for React Category Chart** - [Documentation](https://www.infragistics.com/products/ignite-ui-react/react/components/CategoryChart.html)
*
* The Ignite UI Category Chart is a lightweight, highly performant chart. It can be easily configured to display category data using an extremely simple and intuitive API. All you need to do is provide your data to the chart and it will take care of everything else.
*
* Example:
*
* ```ts
* <IgrCategoryChart
* 	dataSource={this.state.data} />
* ```
*/
export declare class IgrCategoryChart extends IgrXYChart<IIgrCategoryChartProps> {
    private _container;
    private _height;
    private _width;
    private _initialized;
    private _elRef;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    protected _tooltipRef(t: any): void;
    private _getMainRef;
    render(): React.DetailedReactHTMLElement<{
        className: string;
        ref: (ref: any) => void;
        children: any[];
    }, any>;
    constructor(props: IIgrCategoryChartProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    destroy(): void;
    private _wrapper;
    protected createImplementation(): CategoryChart;
    get i(): CategoryChart;
    protected createSeriesComponent(type: string): any;
    protected createSeries(type: DataSeriesType): any;
    private _chart;
    private _dataSource;
    set dataSource(value: Array<any>);
    get dataSource(): Array<any>;
    bindData(): void;
    private _defaultTooltips;
    initializeContent(): void;
    private _activeTooltips;
    private _activeTooltipElements;
    private _currentTooltips;
    private _uniqueTooltipId;
    private createTooltip;
    private _ensureTooltipCreated;
    private _createXAxis;
    private _createYAxis;
    private _ensureDefaultTooltip;
    private _onDefaultTooltipsReady;
    private _updateTooltipState;
    /**
 * Gets or sets the duration used for animating series plots when the chart is loading into view
*
* `TransitionInDuration` controls the length of time taken by the transition-in animation.  Try setting it to 2 seconds:
*
* ```ts
* <IgrCategoryChart
* 	dataSource={this.state.data}
* 	transitionInDuration={2000} />
* ```
*/
    get transitionInDuration(): number;
    set transitionInDuration(v: number);
    /**
     * Gets or sets the duration used for animating series plots when the series is leaving view
    */
    get transitionOutDuration(): number;
    set transitionOutDuration(v: number);
    /**
     * Gets or sets the easing function used for animating series plots when the chart is loading into view
     * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
    */
    get transitionInEasingFunction(): (time: number) => number;
    set transitionInEasingFunction(v: (time: number) => number);
    /**
     * Gets or sets the easing function used for animating series plots when the chart is loading into view
     * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
    */
    get transitionOutEasingFunction(): (time: number) => number;
    set transitionOutEasingFunction(v: (time: number) => number);
    /**
     * Gets domain type of this chart
    */
    get domainType(): DomainType;
    /**
     * Gets or sets the type of chart series to generate from the data.
    *
    * The `ChartType` property determines the type of data series to display.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	chartType="stepArea" />
    * ```
    */
    get chartType(): CategoryChartType;
    set chartType(v: CategoryChartType);
    /**
     * Gets or sets the behavior for markers in each series which are placed too close together for the current view, resulting in a collision.
    *
    * `MarkerCollisionAvoidance` controls the technique the chart uses to avoid overlapping markers.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 markerCollisionAvoidance="none" />
    * ```
    */
    get markerCollisionAvoidance(): CategorySeriesMarkerCollisionAvoidance;
    set markerCollisionAvoidance(v: CategorySeriesMarkerCollisionAvoidance);
    /**
     * Gets or sets whether to include the spline shape in the axis range requested of the axis for spline type series.
    */
    get isSplineShapePartOfRange(): boolean;
    set isSplineShapePartOfRange(v: boolean);
    /**
     * Gets or sets whether animation of series plots is enabled when the chart is loading into view
    *
    * Set `IsTransitionInEnabled` to true if you want your chart series to animate into position when the chart is loading into view.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 isTransitionInEnabled ="true" />
    * ```
    */
    get isTransitionInEnabled(): boolean;
    set isTransitionInEnabled(v: boolean);
    /**
     * Gets or sets the method that determines how to animate series plots when the chart is loading into view
    *
    * `TransitionInMode` controls the direction of the transition-in animation.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	CategoryTransitionInMode="accordionfromRight" />
    * ```
    */
    get transitionInMode(): CategoryTransitionInMode;
    set transitionInMode(v: CategoryTransitionInMode);
    /**
     * Gets or sets the arrival speed used for animating series plots when the chart is loading into view
    *
    * `TransitionInSpeedType` controls the speed of the transition-in animation.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 transitionInSpeedType="indexScaled" >
    * </IgrCategoryChart>
    * ```
    */
    get transitionInSpeedType(): TransitionInSpeedType;
    set transitionInSpeedType(v: TransitionInSpeedType);
    /**
     * Gets or sets the frequency of displayed labels along the X-axis.
     * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
    *
    * `XAxisInterval` determines how often to show a label, tickmark, and/or gridline along the x-axis.  Set this property to _n_ to display a label every _nth_ item.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	xAxisInterval={3} />
    * ```
    */
    get xAxisInterval(): number;
    set xAxisInterval(v: number);
    /**
     * Gets or sets the frequency of displayed minor lines along the X-axis.
     * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
    *
    * `XAxisMinorInterval` determines how often to show a minor gridline along the x-axis.  This property is relevant only when the displayed series is a type with grouping, like column series.
    *
    * `XAxisMinorInterval` is expressed as a number between 0 and 1, representing the frequency of the interval.  To display minor gridlines representing 10ths of an item width, set `XAxisMinorInterval` to 0.1.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	xAxisMinorInterval={0.1}
    *     xAxisMinorStroke="green"
    *     xAxisMinorStrokeThickness={1} />
    * ```
    */
    get xAxisMinorInterval(): number;
    set xAxisMinorInterval(v: number);
    /**
     * Gets or sets the amount of space between adjacent categories for the X-axis.
     * The gap is silently clamped to the range [0, 1] when used.
    *
    * Use the `XAxisGap` property to configure the spacing between items on the x-axis.  This property is relevant only when the displayed series is a type with item spacing, like column series.
    *
    * An `XAxisGap` of 0 allocates no space between items.  An `XAxisGap` of 1 allocates a space between items equal to the width of one item.
    *
    * To set the item spacing to 75% the width of one item, set the `XAxisGap` to 0.75, as in this code:
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 xAxisGap={0.75} />
    * ```
    */
    get xAxisGap(): number;
    set xAxisGap(v: number);
    /**
     * Gets or sets the minimum amount of pixels to use for the gap between categories, if possible.
    */
    get xAxisMinimumGapSize(): number;
    set xAxisMinimumGapSize(v: number);
    /**
     * Gets or sets the maximum gap value to allow. This defaults to 1.0.
    */
    get xAxisMaximumGap(): number;
    set xAxisMaximumGap(v: number);
    /**
     * Gets or sets the amount of overlap between adjacent categories for the X-axis.
     * Gets or sets the overlap is silently clamped to the range [-1, 1] when used.
    *
    * Use the `XAxisOverlap` property to configure the spacing between items on the x-axis.  This property is relevant only when the displayed series is a type with item spacing, like column series.
    *
    * An `XAxisOverlap` of 0 places grouped items adjacent to each other.  An `XAxisOverlap` of 1 places grouped items in the same axis space, completely overlapping.  An `XAxisOverlap` of -1 places a space between grouped items equal to the width of one item.
    *
    * To place grouped items with 75% overlap, set the `XAxisOverlap` to 0.75, as in this code:
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	xAxisOverlap={0} />
    * ```
    */
    get xAxisOverlap(): number;
    set xAxisOverlap(v: number);
    /**
     * Gets or sets the distance between each label and grid line along the Y-axis.
    *
    * `YAxisInterval` determines how often to show a label, tickmark, and/or gridline along the y-axis.  Set this property to a number less than the numeric range of the y-axis.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisInterval={10} />
    * ```
    */
    get yAxisInterval(): number;
    set yAxisInterval(v: number);
    /**
     * Gets or sets a whether the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get autoMarginAndAngleUpdateMode(): AutoMarginsAndAngleUpdateMode;
    set autoMarginAndAngleUpdateMode(v: AutoMarginsAndAngleUpdateMode);
    /**
     * Gets or sets a whether the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get shouldAutoExpandMarginForInitialLabels(): boolean;
    set shouldAutoExpandMarginForInitialLabels(v: boolean);
    /**
     * Gets or sets a whether the series viewer should consider auto rotating labels to fit them in the initial view. This implies that ShouldAutoExpandMarginForInitialLabels is true.
    */
    get shouldConsiderAutoRotationForInitialLabels(): boolean;
    set shouldConsiderAutoRotationForInitialLabels(v: boolean);
    /**
     * Gets or sets the extra amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get autoExpandMarginExtraPadding(): number;
    set autoExpandMarginExtraPadding(v: number);
    /**
     * Gets or sets the maximum amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get autoExpandMarginMaximumValue(): number;
    set autoExpandMarginMaximumValue(v: number);
    /**
     * Gets or sets whether the axis should favor emitting a label at the end of the scale.
    */
    get yAxisFavorLabellingScaleEnd(): boolean;
    set yAxisFavorLabellingScaleEnd(v: boolean);
    /**
     * Gets or sets whether the x axis enhanced interval management should prefer to show all the labels if possible without collisions for supported types of category axes. This is for use with EnhancedIntervalMinimumCharacters = -1 and axes that have an integral interval.
    */
    get xAxisEnhancedIntervalPreferMoreCategoryLabels(): boolean;
    set xAxisEnhancedIntervalPreferMoreCategoryLabels(v: boolean);
    /**
     * Gets or sets whether the y axis enhanced interval management should prefer to show all the labels if possible without collisions for supported types of category axes. This is for use with EnhancedIntervalMinimumCharacters = -1 and axes that have an integral interval.
    */
    get yAxisEnhancedIntervalPreferMoreCategoryLabels(): boolean;
    set yAxisEnhancedIntervalPreferMoreCategoryLabels(v: boolean);
    /**
     * Gets or sets how the numeric axis will adjust its range buffer to less closely fix the data from the series.
    */
    get yAxisAutoRangeBufferMode(): AxisRangeBufferMode;
    set yAxisAutoRangeBufferMode(v: AxisRangeBufferMode);
    /**
     * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
     * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
    *
    * Set `YAxisIsLogarithmic` to true if you want the y-axis to be a logarithmic scale.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisIsLogarithmic="true" />
    * ```
    */
    get yAxisIsLogarithmic(): boolean;
    set yAxisIsLogarithmic(v: boolean);
    /**
     * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
     * This property is effective only when YAxisIsLogarithmic is true.
    *
    * When `YAxisIsLogarithmic` is true, `YAxisLogarithmBase` sets the logarithm base of the y-axis scale.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisIsLogarithmic="true"
    *     yAxisLogarithmBase={2} />
    * ```
    */
    get yAxisLogarithmBase(): number;
    set yAxisLogarithmBase(v: number);
    /**
     * Gets or sets the data value corresponding to the minimum value of the Y-axis.
    *
    * `YAxisMaximumValue` determines the minimum of the y-axis.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisMinimumValue={42} />
    * ```
    */
    get yAxisMinimumValue(): number;
    set yAxisMinimumValue(v: number);
    /**
     * Gets or sets the data value corresponding to the maximum value of the Y-axis.
    *
    * `YAxisMaximumValue` determines the maximum of the y-axis.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisMaximumValue={150} />
    * ```
    */
    get yAxisMaximumValue(): number;
    set yAxisMaximumValue(v: number);
    /**
     * Gets or sets the frequency of displayed minor lines along the Y-axis.
    *
    * `YAxisMinorInterval` determines how often to show a minor gridline along the y-axis.  Set this property to a number less than the y-axis interval.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisMinorInterval={2}
    *     yAxisMinorStroke="green"
    *     yAxisMinorStrokeThickness={1} >
    * </IgrCategoryChart>
    * ```
    */
    get yAxisMinorInterval(): number;
    set yAxisMinorInterval(v: number);
    /**
     * Gets the current minimum value for the X-axis.
    */
    get xAxisActualMinimum(): number;
    /**
     * Gets the current maximum value for the X-axis.
    */
    get xAxisActualMaximum(): number;
    /**
     * Gets the current minimum value for the Y-axis.
    */
    get yAxisActualMinimum(): number;
    /**
     * Gets the current maximum value for the Y-axis.
    */
    get yAxisActualMaximum(): number;
    /**
     * Gets or sets the palette used for coloring negative items of Waterfall chart type.
    *
    * `NegativeBrushes` controls the brushes used by the chart for negative data, when the `ChartType` is one that supports negative brushes.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	negativeBrushes="#ff0000, #cc0000, #aa0000" />
    * ```
    */
    get negativeBrushes(): string[];
    set negativeBrushes(v: string[]);
    /**
     * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
    *
    * `NegativeOutlines` controls the outlines used by the chart for negative data, when the `ChartType` is one that supports negative brushes.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	negativeOutlines="#0000ff, #0000cc, #0000aa" />
    * ```
    */
    get negativeOutlines(): string[];
    set negativeOutlines(v: string[]);
    /**
     * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
    *
    * To abbreviate on the y-axis using formats like "1K" or "1M," set `YAxisAbbreviateLargeNumbers` to true.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisAbbreviateLargeNumbers="true" >
    * </IgrCategoryChart>
    * ```
    */
    get yAxisAbbreviateLargeNumbers(): boolean;
    set yAxisAbbreviateLargeNumbers(v: boolean);
    /**
     * Gets or sets number of visible categories at maximum zooming level
     * This property is overridden by chart's WindowRectMinWidth property
    */
    get xAxisZoomMaximumCategoryRange(): number;
    set xAxisZoomMaximumCategoryRange(v: number);
    /**
     * Gets or sets maximum pixel span of series item that will be visible at maximum zooming level
     * This property ensures that series item does not get stretch above specified value.
     * This property is overridden by chart's WindowRectMinWidth property
    */
    get xAxisZoomMaximumItemSpan(): number;
    set xAxisZoomMaximumItemSpan(v: number);
    /**
     * Gets or sets number of categories that the chart will zoom in and fill plot area
     * This property is overridden by chart's WindowRect or WindowScaleHorizontal properties
    */
    get xAxisZoomToCategoryRange(): number;
    set xAxisZoomToCategoryRange(v: number);
    /**
     * Gets or sets starting category that chart will move its zoom window. Acceptable value is between 0 and number of data items
     * This property is overridden by chart's WindowRect or WindowScaleHorizontal properties
    */
    get xAxisZoomToCategoryStart(): number;
    set xAxisZoomToCategoryStart(v: number);
    /**
     * Gets or sets pixel span of series item that will be used to zoom chart such that the item has desired span
     * Chart will automaticlly zoom in until series item has specified pixel span.
     * This property is overridden by chart's WindowRect or WindowScaleHorizontal properties
    */
    get xAxisZoomToItemSpan(): number;
    set xAxisZoomToItemSpan(v: number);
    /**
     * Gets or sets whether the category should be highlighted when hovered
    */
    get isCategoryHighlightingEnabled(): boolean;
    set isCategoryHighlightingEnabled(v: boolean);
    /**
     * Gets or sets whether the item should be highlighted when hovered
    */
    get isItemHighlightingEnabled(): boolean;
    set isItemHighlightingEnabled(v: boolean);
    /**
 * Export serialized visual data.

*/
    exportSerializedVisualData(): string;
    recalculateMarginAutoExpansion(): void;
    getCurrentXAxisActualMinimum(): number;
    getCurrentYAxisActualMinimum(): number;
    getCurrentXAxisActualMaximum(): number;
    getCurrentYAxisActualMaximum(): number;
}
export interface IIgrCategoryChartProps extends IIgrXYChartProps {
    width?: string;
    height?: string;
    legend?: any;
    /**
  * Gets or sets the data for the chart to use. This can be overriden at the series and axis level.
  */
    dataSource?: any[];
    /**
 * Gets or sets the duration used for animating series plots when the chart is loading into view
*
* `TransitionInDuration` controls the length of time taken by the transition-in animation.  Try setting it to 2 seconds:
*
* ```ts
* <IgrCategoryChart
* 	dataSource={this.state.data}
* 	transitionInDuration={2000} />
* ```
*/
    transitionInDuration?: number | string;
    /**
     * Gets or sets the duration used for animating series plots when the series is leaving view
    */
    transitionOutDuration?: number | string;
    /**
     * Gets or sets the easing function used for animating series plots when the chart is loading into view
     * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
    */
    transitionInEasingFunction?: (time: number) => number;
    /**
     * Gets or sets the easing function used for animating series plots when the chart is loading into view
     * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
    */
    transitionOutEasingFunction?: (time: number) => number;
    /**
     * Gets or sets the type of chart series to generate from the data.
    *
    * The `ChartType` property determines the type of data series to display.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	chartType="stepArea" />
    * ```
    */
    chartType?: CategoryChartType | string;
    /**
     * Gets or sets the behavior for markers in each series which are placed too close together for the current view, resulting in a collision.
    *
    * `MarkerCollisionAvoidance` controls the technique the chart uses to avoid overlapping markers.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 markerCollisionAvoidance="none" />
    * ```
    */
    markerCollisionAvoidance?: CategorySeriesMarkerCollisionAvoidance | string;
    /**
     * Gets or sets whether to include the spline shape in the axis range requested of the axis for spline type series.
    */
    isSplineShapePartOfRange?: boolean | string;
    /**
     * Gets or sets whether animation of series plots is enabled when the chart is loading into view
    *
    * Set `IsTransitionInEnabled` to true if you want your chart series to animate into position when the chart is loading into view.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 isTransitionInEnabled ="true" />
    * ```
    */
    isTransitionInEnabled?: boolean | string;
    /**
     * Gets or sets the method that determines how to animate series plots when the chart is loading into view
    *
    * `TransitionInMode` controls the direction of the transition-in animation.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	CategoryTransitionInMode="accordionfromRight" />
    * ```
    */
    transitionInMode?: CategoryTransitionInMode | string;
    /**
     * Gets or sets the arrival speed used for animating series plots when the chart is loading into view
    *
    * `TransitionInSpeedType` controls the speed of the transition-in animation.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 transitionInSpeedType="indexScaled" >
    * </IgrCategoryChart>
    * ```
    */
    transitionInSpeedType?: TransitionInSpeedType | string;
    /**
     * Gets or sets the frequency of displayed labels along the X-axis.
     * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
    *
    * `XAxisInterval` determines how often to show a label, tickmark, and/or gridline along the x-axis.  Set this property to _n_ to display a label every _nth_ item.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	xAxisInterval={3} />
    * ```
    */
    xAxisInterval?: number | string;
    /**
     * Gets or sets the frequency of displayed minor lines along the X-axis.
     * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
    *
    * `XAxisMinorInterval` determines how often to show a minor gridline along the x-axis.  This property is relevant only when the displayed series is a type with grouping, like column series.
    *
    * `XAxisMinorInterval` is expressed as a number between 0 and 1, representing the frequency of the interval.  To display minor gridlines representing 10ths of an item width, set `XAxisMinorInterval` to 0.1.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	xAxisMinorInterval={0.1}
    *     xAxisMinorStroke="green"
    *     xAxisMinorStrokeThickness={1} />
    * ```
    */
    xAxisMinorInterval?: number | string;
    /**
     * Gets or sets the amount of space between adjacent categories for the X-axis.
     * The gap is silently clamped to the range [0, 1] when used.
    *
    * Use the `XAxisGap` property to configure the spacing between items on the x-axis.  This property is relevant only when the displayed series is a type with item spacing, like column series.
    *
    * An `XAxisGap` of 0 allocates no space between items.  An `XAxisGap` of 1 allocates a space between items equal to the width of one item.
    *
    * To set the item spacing to 75% the width of one item, set the `XAxisGap` to 0.75, as in this code:
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	 xAxisGap={0.75} />
    * ```
    */
    xAxisGap?: number | string;
    /**
     * Gets or sets the minimum amount of pixels to use for the gap between categories, if possible.
    */
    xAxisMinimumGapSize?: number | string;
    /**
     * Gets or sets the maximum gap value to allow. This defaults to 1.0.
    */
    xAxisMaximumGap?: number | string;
    /**
     * Gets or sets the amount of overlap between adjacent categories for the X-axis.
     * Gets or sets the overlap is silently clamped to the range [-1, 1] when used.
    *
    * Use the `XAxisOverlap` property to configure the spacing between items on the x-axis.  This property is relevant only when the displayed series is a type with item spacing, like column series.
    *
    * An `XAxisOverlap` of 0 places grouped items adjacent to each other.  An `XAxisOverlap` of 1 places grouped items in the same axis space, completely overlapping.  An `XAxisOverlap` of -1 places a space between grouped items equal to the width of one item.
    *
    * To place grouped items with 75% overlap, set the `XAxisOverlap` to 0.75, as in this code:
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	xAxisOverlap={0} />
    * ```
    */
    xAxisOverlap?: number | string;
    /**
     * Gets or sets the distance between each label and grid line along the Y-axis.
    *
    * `YAxisInterval` determines how often to show a label, tickmark, and/or gridline along the y-axis.  Set this property to a number less than the numeric range of the y-axis.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisInterval={10} />
    * ```
    */
    yAxisInterval?: number | string;
    /**
     * Gets or sets a whether the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    autoMarginAndAngleUpdateMode?: AutoMarginsAndAngleUpdateMode | string;
    /**
     * Gets or sets a whether the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    shouldAutoExpandMarginForInitialLabels?: boolean | string;
    /**
     * Gets or sets a whether the series viewer should consider auto rotating labels to fit them in the initial view. This implies that ShouldAutoExpandMarginForInitialLabels is true.
    */
    shouldConsiderAutoRotationForInitialLabels?: boolean | string;
    /**
     * Gets or sets the extra amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    autoExpandMarginExtraPadding?: number | string;
    /**
     * Gets or sets the maximum amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    autoExpandMarginMaximumValue?: number | string;
    /**
     * Gets or sets whether the axis should favor emitting a label at the end of the scale.
    */
    yAxisFavorLabellingScaleEnd?: boolean | string;
    /**
     * Gets or sets whether the x axis enhanced interval management should prefer to show all the labels if possible without collisions for supported types of category axes. This is for use with EnhancedIntervalMinimumCharacters = -1 and axes that have an integral interval.
    */
    xAxisEnhancedIntervalPreferMoreCategoryLabels?: boolean | string;
    /**
     * Gets or sets whether the y axis enhanced interval management should prefer to show all the labels if possible without collisions for supported types of category axes. This is for use with EnhancedIntervalMinimumCharacters = -1 and axes that have an integral interval.
    */
    yAxisEnhancedIntervalPreferMoreCategoryLabels?: boolean | string;
    /**
     * Gets or sets how the numeric axis will adjust its range buffer to less closely fix the data from the series.
    */
    yAxisAutoRangeBufferMode?: AxisRangeBufferMode | string;
    /**
     * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
     * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
    *
    * Set `YAxisIsLogarithmic` to true if you want the y-axis to be a logarithmic scale.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisIsLogarithmic="true" />
    * ```
    */
    yAxisIsLogarithmic?: boolean | string;
    /**
     * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
     * This property is effective only when YAxisIsLogarithmic is true.
    *
    * When `YAxisIsLogarithmic` is true, `YAxisLogarithmBase` sets the logarithm base of the y-axis scale.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisIsLogarithmic="true"
    *     yAxisLogarithmBase={2} />
    * ```
    */
    yAxisLogarithmBase?: number | string;
    /**
     * Gets or sets the data value corresponding to the minimum value of the Y-axis.
    *
    * `YAxisMaximumValue` determines the minimum of the y-axis.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisMinimumValue={42} />
    * ```
    */
    yAxisMinimumValue?: number | string;
    /**
     * Gets or sets the data value corresponding to the maximum value of the Y-axis.
    *
    * `YAxisMaximumValue` determines the maximum of the y-axis.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisMaximumValue={150} />
    * ```
    */
    yAxisMaximumValue?: number | string;
    /**
     * Gets or sets the frequency of displayed minor lines along the Y-axis.
    *
    * `YAxisMinorInterval` determines how often to show a minor gridline along the y-axis.  Set this property to a number less than the y-axis interval.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisMinorInterval={2}
    *     yAxisMinorStroke="green"
    *     yAxisMinorStrokeThickness={1} >
    * </IgrCategoryChart>
    * ```
    */
    yAxisMinorInterval?: number | string;
    /**
     * Gets or sets the palette used for coloring negative items of Waterfall chart type.
    *
    * `NegativeBrushes` controls the brushes used by the chart for negative data, when the `ChartType` is one that supports negative brushes.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	negativeBrushes="#ff0000, #cc0000, #aa0000" />
    * ```
    */
    negativeBrushes?: string[] | string;
    /**
     * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
    *
    * `NegativeOutlines` controls the outlines used by the chart for negative data, when the `ChartType` is one that supports negative brushes.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	negativeOutlines="#0000ff, #0000cc, #0000aa" />
    * ```
    */
    negativeOutlines?: string[] | string;
    /**
     * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
    *
    * To abbreviate on the y-axis using formats like "1K" or "1M," set `YAxisAbbreviateLargeNumbers` to true.
    *
    * ```ts
    * <IgrCategoryChart
    * 	dataSource={this.state.data}
    * 	yAxisAbbreviateLargeNumbers="true" >
    * </IgrCategoryChart>
    * ```
    */
    yAxisAbbreviateLargeNumbers?: boolean | string;
    /**
     * Gets or sets number of visible categories at maximum zooming level
     * This property is overridden by chart's WindowRectMinWidth property
    */
    xAxisZoomMaximumCategoryRange?: number | string;
    /**
     * Gets or sets maximum pixel span of series item that will be visible at maximum zooming level
     * This property ensures that series item does not get stretch above specified value.
     * This property is overridden by chart's WindowRectMinWidth property
    */
    xAxisZoomMaximumItemSpan?: number | string;
    /**
     * Gets or sets number of categories that the chart will zoom in and fill plot area
     * This property is overridden by chart's WindowRect or WindowScaleHorizontal properties
    */
    xAxisZoomToCategoryRange?: number | string;
    /**
     * Gets or sets starting category that chart will move its zoom window. Acceptable value is between 0 and number of data items
     * This property is overridden by chart's WindowRect or WindowScaleHorizontal properties
    */
    xAxisZoomToCategoryStart?: number | string;
    /**
     * Gets or sets pixel span of series item that will be used to zoom chart such that the item has desired span
     * Chart will automaticlly zoom in until series item has specified pixel span.
     * This property is overridden by chart's WindowRect or WindowScaleHorizontal properties
    */
    xAxisZoomToItemSpan?: number | string;
    /**
     * Gets or sets whether the category should be highlighted when hovered
    */
    isCategoryHighlightingEnabled?: boolean | string;
    /**
     * Gets or sets whether the item should be highlighted when hovered
    */
    isItemHighlightingEnabled?: boolean | string;
}
