import { IgPoint } from "igniteui-react-core";
import { IgrNumericAngleAxis } from "./igr-numeric-angle-axis";
import { IgrNumericRadiusAxis } from "./igr-numeric-radius-axis";
import { TrendLineType } from "igniteui-react-core";
import { ScatterItemSearchMode } from "./ScatterItemSearchMode";
import { IgrAssigningPolarStyleEventArgs } from "./igr-assigning-polar-style-event-args";
import { IgrAssigningPolarMarkerStyleEventArgs } from "./igr-assigning-polar-marker-style-event-args";
import { IgrMarkerSeries, IIgrMarkerSeriesProps } from "./igr-marker-series";
import { PolarBase } from "./PolarBase";
import { IgrAxis } from "./igr-axis";
/**
 * Represents the base class from which all IgxDataChartComponent polar series are derived.
*/
export declare abstract class IgrPolarBase<P extends IIgrPolarBaseProps = IIgrPolarBaseProps> extends IgrMarkerSeries<P> {
    /**
                                 * @hidden
                                 */
    get i(): PolarBase;
    constructor(props: P);
    /**
     * Checks if this series is a polar series
    */
    get isPolar(): boolean;
    /**
     * Gets or sets the path to use to find the angle values for the series.
    */
    get angleMemberPath(): string;
    set angleMemberPath(v: string);
    /**
     * Gets or sets the path to use to get the radius values for the series.
    */
    get radiusMemberPath(): string;
    set radiusMemberPath(v: string);
    /**
     * Gets or sets the highlighted radius value mapping property for the current series object.
    */
    get highlightedRadiusMemberPath(): string;
    set highlightedRadiusMemberPath(v: string);
    /**
     * Gets or sets the highlighted angle value mapping property for the current series object.
    */
    get highlightedAngleMemberPath(): string;
    set highlightedAngleMemberPath(v: string);
    /**
     * Gets the effective angle axis for the current series object.
    */
    get angleAxis(): IgrNumericAngleAxis;
    set angleAxis(v: IgrNumericAngleAxis);
    private _angleAxisName;
    /**
    * Gets or sets the name to use to resolve angleAxis from markup.
    */
    get angleAxisName(): string;
    set angleAxisName(v: string);
    /**
     * Gets the effective radius axis for the current series object.
    */
    get radiusAxis(): IgrNumericRadiusAxis;
    set radiusAxis(v: IgrNumericRadiusAxis);
    private _radiusAxisName;
    /**
    * Gets or sets the name to use to resolve radiusAxis from markup.
    */
    get radiusAxisName(): string;
    set radiusAxisName(v: string);
    /**
     * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
     * spiral based interpolation.
    */
    get useCartesianInterpolation(): boolean;
    set useCartesianInterpolation(v: boolean);
    /**
     * Gets or sets the maximum number of markers displayed by the current series.
     * If more than the specified number of markers are visible, the polar series will automatically
     * choose a representative set.
    */
    get maximumMarkers(): number;
    set maximumMarkers(v: number);
    /**
     * Gets or sets the trend type for the current series object.
    */
    get trendLineType(): TrendLineType;
    set trendLineType(v: TrendLineType);
    /**
     * Gets or sets the brush that specifies how the current series
     * object's trend line is drawn.
    */
    get trendLineBrush(): string;
    set trendLineBrush(v: string);
    /**
     * Gets the effective TrendLineBrush for this series.
    */
    get actualTrendLineBrush(): string;
    set actualTrendLineBrush(v: string);
    /**
     * Gets or sets the thickness of the current series object's trend line.
    */
    get trendLineThickness(): number;
    set trendLineThickness(v: number);
    /**
     * Gets or sets a collection of double values that indicate the pattern of dashes and gaps that
     * is used to draw the trend line for the current series object.
    */
    get trendLineDashArray(): number[];
    set trendLineDashArray(v: number[]);
    /**
     * Gets or sets the moving average period for the current series object.
    */
    get trendLinePeriod(): number;
    set trendLinePeriod(v: number);
    /**
     * Sets or Gets the Trendline Z index.
    */
    get trendLineZIndex(): number;
    set trendLineZIndex(v: number);
    /**
     * Gets or sets whether to clip the series to the bounds.
     * Setting this to true can effect performance.
    */
    get clipSeriesToBounds(): boolean;
    set clipSeriesToBounds(v: boolean);
    get actualItemSearchMode(): ScatterItemSearchMode;
    set actualItemSearchMode(v: ScatterItemSearchMode);
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode(): ScatterItemSearchMode;
    set itemSearchMode(v: ScatterItemSearchMode);
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold(): number;
    set itemSearchThreshold(v: number);
    /**
     * Gets or sets whether this Polar series should allow custom style overrides of its individual visuals.
    */
    get isCustomPolarStyleAllowed(): boolean;
    set isCustomPolarStyleAllowed(v: boolean);
    /**
     * Gets or sets whether this Polar series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomPolarMarkerStyleAllowed(): boolean;
    set isCustomPolarMarkerStyleAllowed(v: boolean);
    /**
     * Gets or sets the label displayed before series' radius value in the Data Legend.
    */
    get radiusMemberAsLegendLabel(): string;
    set radiusMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the label displayed before series' angle value in the Data Legend.
    */
    get angleMemberAsLegendLabel(): string;
    set angleMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the unit displayed after series' radius value in the Data Legend.
    */
    get radiusMemberAsLegendUnit(): string;
    set radiusMemberAsLegendUnit(v: string);
    /**
     * Gets or sets the unit displayed after series' angle value in the Data Legend.
    */
    get angleMemberAsLegendUnit(): string;
    set angleMemberAsLegendUnit(v: string);
    bindAxes(axes: IgrAxis[]): void;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Scrolls the requested item into view, if possible.
    
    * @param item  * The item to scroll into view.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    getItemIndex(world: IgPoint): number;
    getExactItemIndex(world: IgPoint): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Determine if object can be used as RadiusAxis
    
    * @param axis  * The object to check
    */
    canUseAsRadiusAxis(axis: any): boolean;
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    canUseAsAngleAxis(axis: any): boolean;
    private _assigningPolarStyle;
    private _assigningPolarStyle_wrapped;
    /**
     * Event raised when Assigning Category Style
    */
    get assigningPolarStyle(): (s: IgrPolarBase, e: IgrAssigningPolarStyleEventArgs) => void;
    set assigningPolarStyle(ev: (s: IgrPolarBase, e: IgrAssigningPolarStyleEventArgs) => void);
    private _assigningPolarMarkerStyle;
    private _assigningPolarMarkerStyle_wrapped;
    /**
     * Event raised when Assigning Polar Marker Style
    */
    get assigningPolarMarkerStyle(): (s: IgrPolarBase, e: IgrAssigningPolarMarkerStyleEventArgs) => void;
    set assigningPolarMarkerStyle(ev: (s: IgrPolarBase, e: IgrAssigningPolarMarkerStyleEventArgs) => void);
}
export interface IIgrPolarBaseProps extends IIgrMarkerSeriesProps {
    /**
     * Gets or sets the path to use to find the angle values for the series.
    */
    angleMemberPath?: string;
    /**
     * Gets or sets the path to use to get the radius values for the series.
    */
    radiusMemberPath?: string;
    /**
     * Gets or sets the highlighted radius value mapping property for the current series object.
    */
    highlightedRadiusMemberPath?: string;
    /**
     * Gets or sets the highlighted angle value mapping property for the current series object.
    */
    highlightedAngleMemberPath?: string;
    /**
     * Gets the effective angle axis for the current series object.
    */
    angleAxis?: IgrNumericAngleAxis;
    /**
    * Gets or sets the name to use to resolve angleAxis from markup.
    */
    angleAxisName?: string;
    /**
     * Gets the effective radius axis for the current series object.
    */
    radiusAxis?: IgrNumericRadiusAxis;
    /**
    * Gets or sets the name to use to resolve radiusAxis from markup.
    */
    radiusAxisName?: string;
    /**
     * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
     * spiral based interpolation.
    */
    useCartesianInterpolation?: boolean | string;
    /**
     * Gets or sets the maximum number of markers displayed by the current series.
     * If more than the specified number of markers are visible, the polar series will automatically
     * choose a representative set.
    */
    maximumMarkers?: number | string;
    /**
     * Gets or sets the trend type for the current series object.
    */
    trendLineType?: TrendLineType | string;
    /**
     * Gets or sets the brush that specifies how the current series
     * object's trend line is drawn.
    */
    trendLineBrush?: string;
    /**
     * Gets the effective TrendLineBrush for this series.
    */
    actualTrendLineBrush?: string;
    /**
     * Gets or sets the thickness of the current series object's trend line.
    */
    trendLineThickness?: number | string;
    /**
     * Gets or sets a collection of double values that indicate the pattern of dashes and gaps that
     * is used to draw the trend line for the current series object.
    */
    trendLineDashArray?: number[] | string;
    /**
     * Gets or sets the moving average period for the current series object.
    */
    trendLinePeriod?: number | string;
    /**
     * Sets or Gets the Trendline Z index.
    */
    trendLineZIndex?: number | string;
    /**
     * Gets or sets whether to clip the series to the bounds.
     * Setting this to true can effect performance.
    */
    clipSeriesToBounds?: boolean | string;
    actualItemSearchMode?: ScatterItemSearchMode | string;
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    itemSearchMode?: ScatterItemSearchMode | string;
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    itemSearchThreshold?: number | string;
    /**
     * Gets or sets whether this Polar series should allow custom style overrides of its individual visuals.
    */
    isCustomPolarStyleAllowed?: boolean | string;
    /**
     * Gets or sets whether this Polar series should allow custom style overrides of its individual marker visuals.
    */
    isCustomPolarMarkerStyleAllowed?: boolean | string;
    /**
     * Gets or sets the label displayed before series' radius value in the Data Legend.
    */
    radiusMemberAsLegendLabel?: string;
    /**
     * Gets or sets the label displayed before series' angle value in the Data Legend.
    */
    angleMemberAsLegendLabel?: string;
    /**
     * Gets or sets the unit displayed after series' radius value in the Data Legend.
    */
    radiusMemberAsLegendUnit?: string;
    /**
     * Gets or sets the unit displayed after series' angle value in the Data Legend.
    */
    angleMemberAsLegendUnit?: string;
    /**
     * Event raised when Assigning Category Style
    */
    assigningPolarStyle?: (s: IgrPolarBase, e: IgrAssigningPolarStyleEventArgs) => void;
    /**
     * Event raised when Assigning Polar Marker Style
    */
    assigningPolarMarkerStyle?: (s: IgrPolarBase, e: IgrAssigningPolarMarkerStyleEventArgs) => void;
}
